# Federation

There isn't a lot here aside from a homeserver resolver. A lot of the federation is already handled by
matrix-nio itself, so there isn't a lot of need for federation-specific utilities.

::: niobot.utils.federation
